import appConfig from './config';
import router from './../router';

const codeMessage = {
    200: '服务器成功返回请求的数据。',
    201: '新建或修改数据成功。',
    202: '一个请求已经进入后台排队（异步任务）。',
    204: '删除数据成功。',
    400: '发出的请求有错误，服务器没有进行新建或修改数据的操作。',
    401: '用户没有权限（令牌、用户名、密码错误）。',
    403: '用户得到授权，但是访问是被禁止的。',
    404: '发出的请求针对的是不存在的记录，服务器没有进行操作。',
    406: '请求的格式不可得。',
    410: '请求的资源被永久删除，且不会再得到的。',
    422: '当创建一个对象时，发生一个验证错误。',
    500: '服务器发生错误，请检查服务器。',
    502: '网关错误。',
    503: '服务不可用，服务器暂时过载或维护。',
    504: '网关超时。',
};


export function get(api) {
    return new Promise((resolve, reject) => {
        api += (api.search(/\?/) === -1 ? '?' : '&') + 'token=' + appConfig.getUserToken();
        fetch(appConfig.apiUrl + api, {
            method: 'GET',
        }).then(res => {
            return res.json();
        }).then(data => {
            if (data.code && data.code == 401) {
                gotoLogin()
            } else {
                resolve(data);
            }
        }).catch(data => {
            reject(data)
        })
    })
}

export function buildUrl(api) {
    return appConfig.apiUrl + api + (api.search(/\?/) === -1 ? '?' : '&') + 'token=' + appConfig.getUserToken();
}

// import {Message} from 'element-ui';

const gotoLogin = () => {
    router.replace({
        path: '/user/login',
        query: {redirect: router.currentRoute.path},
    })
}

/**
 * 发送post请求
 * @param {string} api
 * @param {object} data
 */
export function post(api, postData) {
    return new Promise((resolve, reject) => {
        api += (api.search(/\?/) === -1 ? '?' : '&') + 'token=' + appConfig.getUserToken();
        let formData = new FormData();
        for (var k in postData) {
            formData.append(k, postData[k]);
        }
        fetch(appConfig.apiUrl + api, {
            method: 'POST',
            mode: 'cors',
            // headers: {
            //     'Content-Type': 'application/x-www-form-urlencoded'
            // },
            body: formData //JSON.stringify(postData)
        }).then(res => {
            return res.json();
        }).then(data => {
            if (data.code && data.code == 401) {
                gotoLogin()
            } else {
                resolve(data);
            }
        }).catch(data => {
            reject(data)
        })
    })
}

export default {
    get, post, buildUrl
}